@@ -15,8 +15,7 @@ from trytond.pool import Pool
 from trytond import backend
 
 __all__ = ['Line', 'EnterLinesStart', 'EnterLines',
-    'HoursEmployee',
-    'OpenHoursEmployeeStart', 'OpenHoursEmployee',
+    'HoursEmployee', 'HoursEmployeeContext',
     'HoursEmployeeWeekly', 'HoursEmployeeMonthly']
 
 
@@ -27,14 +26,21 @@ class Line(ModelSQL, ModelView):
     employee = fields.Many2One('company.employee', 'Employee', required=True,
         select=True, domain=[
             ('company', '=', Eval('company', -1)),
+            ['OR',
+                ('start_date', '=', None),
+                ('start_date', '<=', Eval('date')),
+                ],
+            ['OR',
+                ('end_date', '=', None),
+                ('end_date', '>=', Eval('date')),
+                ],
             ],
-        depends=['company'])
+        depends=['company', 'date'])
     date = fields.Date('Date', required=True, select=True)
     duration = fields.TimeDelta('Duration', 'company_work_time', required=True)
     work = fields.Many2One('timesheet.work', 'Work',
         required=True, select=True, domain=[
             ('company', '=', Eval('company', -1)),
-            ('timesheet_available', '=', True),
             ['OR',
                 ('timesheet_start_date', '=', None),
                 ('timesheet_start_date', '<=', Eval('date')),
@@ -111,14 +117,6 @@ class Line(ModelSQL, ModelView):
         Date_ = Pool().get('ir.date')
         return Transaction().context.get('date') or Date_.today()
 
-    @classmethod
-    def view_header_get(cls, value, view_type='form'):
-        if not Transaction().context.get('employee'):
-            return value
-        Employee = Pool().get('company.employee')
-        employee = Employee(Transaction().context['employee'])
-        return value + " (" + employee.rec_name + ")"
-
     @classmethod
     def validate(cls, lines):
         super(Line, cls).validate(lines)
@@ -140,7 +138,18 @@ class EnterLinesStart(ModelView):
     'Enter Lines'
     __name__ = 'timesheet.line.enter.start'
     employee = fields.Many2One('company.employee', 'Employee', required=True,
-            domain=[('company', '=', Eval('context', {}).get('company', -1))])
+        domain=[
+            ('company', '=', Eval('context', {}).get('company', -1)),
+            ['OR',
+                ('start_date', '=', None),
+                ('start_date', '<=', Eval('date')),
+                ],
+            ['OR',
+                ('end_date', '=', None),
+                ('end_date', '>=', Eval('date')),
+                ],
+            ],
+        depends=['date'])
     date = fields.Date('Date', required=True)
 
     @staticmethod
@@ -212,34 +221,13 @@ class HoursEmployee(ModelSQL, ModelView):
             group_by=line.employee)
 
 
-class OpenHoursEmployeeStart(ModelView):
-    'Open Hours per Employee'
-    __name__ = 'timesheet.hours_employee.open.start'
+class HoursEmployeeContext(ModelView):
+    'Hours per Employee Context'
+    __name__ = 'timesheet.hours_employee.context'
     start_date = fields.Date('Start Date')
     end_date = fields.Date('End Date')
 
 
-class OpenHoursEmployee(Wizard):
-    'Open Hours per Employee'
-    __name__ = 'timesheet.hours_employee.open'
-    start = StateView('timesheet.hours_employee.open.start',
-        'timesheet.hours_employee_open_start_view_form', [
-            Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Open', 'open_', 'tryton-ok', default=True),
-            ])
-    open_ = StateAction('timesheet.act_hours_employee_form')
-
-    def do_open_(self, action):
-        action['pyson_context'] = PYSONEncoder().encode({
-                'start_date': self.start.start_date,
-                'end_date': self.start.end_date,
-                })
-        return action, {}
-
-    def transition_open_(self):
-        return 'end'
-
-
 class HoursEmployeeWeekly(ModelSQL, ModelView):
     'Hours per Employee per Week'
     __name__ = 'timesheet.hours_employee_weekly'
